psiform: A tail-based test statistics (TTS) for differential...

Description Usage Arguments Value

View source: R/2-1-psiform.R

Description

A tail-based test statistics (TTS) for differential expression detection.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
psiform(
  ...,
  y,
  G = NULL,
  dim_u = 5,
  weight = "none",
  scale = FALSE,
  lambda = NULL,
  a = 3.7,
  param_init = NULL,
  n_iter = 100,
  epsilon = 10^-8,
  conv_thresh = 10^-6,
  method = 1
)

Arguments

...

One or multiple matrices of expression levels from multiple platforms.

y

Subject labels.

G

Pathway information.

dim_u

Number of dimension of u.

weight

Type of weight on the pathway. Possible values include "sqrt-degree", "none" or "degree". The default is "none".

scale

Whether to scale input matrices.

lambda

Hyper-parameters in SCAD, TLP, and L1 of phenotype differences.

a

Hyper-parameter in SCAD. Default is 3.7.

param_init

If not NULL, should be a list including c, beta, u, v and sigma_sq.

n_iter

Number of maximum iterations.

epsilon

A small number to avoid zero-denominators.

conv_thresh

Threshold for convergence.

method

Type of TLP.

Value

Returns a Psiform object.


SkadiEye/Psiform documentation built on May 15, 2020, 12:13 a.m.