Description Usage Arguments Value
A tail-based test statistics (TTS) for differential expression detection.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 |
... |
One or multiple matrices of expression levels from multiple platforms. |
y |
Subject labels. |
G |
Pathway information. |
dim_u |
Number of dimension of u. |
weight |
Type of weight on the pathway. Possible values include "sqrt-degree", "none" or "degree". The default is "none". |
scale |
Whether to scale input matrices. |
lambda |
Hyper-parameters in SCAD, TLP, and L1 of phenotype differences. |
a |
Hyper-parameter in SCAD. Default is 3.7. |
param_init |
If not NULL, should be a list including c, beta, u, v and sigma_sq. |
n_iter |
Number of maximum iterations. |
epsilon |
A small number to avoid zero-denominators. |
conv_thresh |
Threshold for convergence. |
method |
Type of TLP. |
Returns a Psiform object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.